==> SV1000-Linux.SV1.2.109.tar.gz: SpliceCom/WebManager/admin/alternateroute/drActions.php <==
<?php

	require('../assets/inc/ldapConnect.php');
	$url = $_SERVER['SERVER_ADDR'];
	$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL;
	$ddiPlan = (isset($_REQUEST['ddiPlan']) && strlen($_REQUEST['ddiPlan']) >=1 ) ? $_REQUEST['ddiPlan'] : NULL;
	
	$db = new SQLite3('DDIRoutes.db3') or die('Unable to open database');
	
	if ($mode === 'save') {
		
		$backup = "Backup ".date('d.m.y His')." - PreAltDDIUpdate.txt";
		$ent["dobackupto"][0] = $backup; ldap_modify($ds,"cn=Commands", $ent); $ent='';
		
		$guid = (isset($_REQUEST['guid']) && count($_REQUEST['guid']) >=1 ) ? $_REQUEST['guid'] : '';
		$numbermatch = (isset($_REQUEST['numbermatch']) && count($_REQUEST['numbermatch']) >=1 ) ? $_REQUEST['numbermatch'] : '';
		$translateto = (isset($_REQUEST['translateto']) && count($_REQUEST['translateto']) >=1 ) ? $_REQUEST['translateto'] : '';
		$alternatenumber = (isset($_REQUEST['alternateNumber']) && count($_REQUEST['alternateNumber']) >=1 ) ? $_REQUEST['alternateNumber'] : '';
		$drmode = (isset($_REQUEST['drMode']) && count($_REQUEST['drMode']) >=1 ) ? $_REQUEST['drMode'] : '0';
		
		
		foreach ($numbermatch as $k => $v) {

			if (strlen($translateto[$k]) >=1 && strlen($alternatenumber[$k]) >=1) { // todo
				$conn = $db->query("SELECT translateto, alternatenumber, drmode FROM routes WHERE ddiplan = '$ddiPlan' AND guid = '$guid[$k]'");
				$results = $conn->fetchArray(1);
				
				$resTranslateTo = $results['translateto'];
				$resAltNumber = $results['alternatenumber'];
				$resDrMode = $results['drmode'];
				
			if ($resTranslateTo != $translateto[$k] || $resAltNumber != $alternatenumber[$k] || $resDrMode != $drmode[$k]) {
				
				if ($results) {
					// update
					echo "update";
					$db->exec("UPDATE routes SET translateto='$translateto[$k]', alternatenumber='$alternatenumber[$k]', drmode='$drmode[$k]' WHERE guid='$guid[$k]'");
				
				} else {
					// add
					echo "add";
					$db->exec("INSERT INTO routes (guid, ddiplan, numbermatch, translateto, alternatenumber, drmode) VALUES ('$guid[$k]', '$ddiPlan', '$numbermatch[$k]', '$translateto[$k]', '$alternatenumber[$k]', '$drmode[$k]')");
				}
			} 
			
				
			} if (strlen($alternatenumber[$k]) < 1 && $drmode[$k] == 0) {
				// delete
				echo "delete";
				$db->exec("DELETE FROM routes WHERE guid='$guid[$k]'");
			} // todo check
			ldap_modify($ds,"guid=$guid[$k]",array('translateto' => $translateto[$k]));
		}
	}
?>

==> SV1000-Linux.SV1.3.82.tar.gz: SpliceCom/WebManager/admin/alternateroute/drActions.php <==
<?php

	require('../assets/inc/ldapConnect.php');
	$url = $_SERVER['SERVER_ADDR'];
	$mode = (isset($_REQUEST['mode']) && strlen($_REQUEST['mode']) >=1 ) ? $_REQUEST['mode'] : NULL;
	$ddiPlan = (isset($_REQUEST['ddiPlan']) && strlen($_REQUEST['ddiPlan']) >=1 ) ? $_REQUEST['ddiPlan'] : NULL;
	$timestamp = (isset($_REQUEST['timestamp']) && strlen($_REQUEST['timestamp']) >=1 ) ? $_REQUEST['timestamp'] : NULL;
	
	$db = new SQLite3('DDIRoutes.db3') or die('Unable to open database');
	
	if ($mode === 'save') {
		
		$backup = "Backup ".date('d.m.y His')." - PreAltDDIUpdate.txt";
		$ent["dobackupto"][0] = $backup; 
		ldap_modify($ds,"cn=Commands", $ent); $ent='';
		
		$guid = (isset($_REQUEST['guid']) && count($_REQUEST['guid']) >=1 ) ? $_REQUEST['guid'] : '';
		$numbermatch = (isset($_REQUEST['numbermatch']) && count($_REQUEST['numbermatch']) >=1 ) ? $_REQUEST['numbermatch'] : '';
		$translateto = (isset($_REQUEST['translateto']) && count($_REQUEST['translateto']) >=1 ) ? $_REQUEST['translateto'] : '';
		$alternatenumber = (isset($_REQUEST['alternateNumber']) && count($_REQUEST['alternateNumber']) >=1 ) ? $_REQUEST['alternateNumber'] : '';
		$drmode = (isset($_REQUEST['drMode']) && count($_REQUEST['drMode']) >=1 ) ? $_REQUEST['drMode'] : '0';
		
		
		foreach ($numbermatch as $k => $v) {

			if (strlen($translateto[$k]) >=1 && strlen($alternatenumber[$k]) >=1) { // todo
				$conn = $db->query("SELECT translateto, alternatenumber, drmode FROM routes WHERE ddiplan = '$ddiPlan' AND guid = '$guid[$k]'");
				$results = $conn->fetchArray(1);
				
				$resTranslateTo = $results['translateto'];
				$resAltNumber = $results['alternatenumber'];
				$resDrMode = $results['drmode'];
				
			if ($resTranslateTo != $translateto[$k] || $resAltNumber != $alternatenumber[$k] || $resDrMode != $drmode[$k]) {
				
				if ($results) {
					// update
					echo "update";
					$db->exec("UPDATE routes SET translateto='$translateto[$k]', alternatenumber='$alternatenumber[$k]', drmode='$drmode[$k]' WHERE guid='$guid[$k]'");
					audit($timestamp, "[ALTDDI] [Update] Update Entry in SQL DB", "Translate To: $translateto[$k]<br>Alternate Number: $alternatenumber[$k]<br>DR Mode: $drmode[$k]<br>GUID: $guid[$k]");
				} else {
					// add
					echo "add";
					$db->exec("INSERT INTO routes (guid, ddiplan, numbermatch, translateto, alternatenumber, drmode) VALUES ('$guid[$k]', '$ddiPlan', '$numbermatch[$k]', '$translateto[$k]', '$alternatenumber[$k]', '$drmode[$k]')");
					audit($timestamp, "[ALTDDI] [Add] Add Entry in SQL DB", "DDIPlan: $ddiPlan<br>Translate To: $translateto[$k]<br>Alternate Number: $alternatenumber[$k]<br>DR Mode: $drmode[$k]<br>GUID: $guid[$k]");
				}
			} 
			
				
			} if (strlen($alternatenumber[$k]) < 1 && $drmode[$k] == 0) {
				// delete
				echo "delete";
				$db->exec("DELETE FROM routes WHERE guid='$guid[$k]'");
				audit($timestamp, "[ALTDDI] [Delete] Delete Entry From SQL DB", "GUID: $guid[$k]<br>Translate To: $translateto[$k]");
			} 
			
			ldap_modify($ds,"guid=$guid[$k]",array('translateto' => $translateto[$k]));
			audit($timestamp, "[ALTDDI] [Update] DDI Entry", "GUID: $guid[$k]<br>Translate To: $translateto[$k]");
		}
	}
?>
